@@ -924,20 +924,19 @@ void Audio::startRolling()
          && MusEGlobal::song->click()
          && !MusEGlobal::extSyncFlag.value()
          && MusEGlobal::song->record()) {
-// DELETETHIS 14 or keep?
-/*
+          printf("state = PRECOUNT!\n");
             state = PRECOUNT;
             int z, n;
-            if (precountFromMastertrackFlag)
-                  AL::sigmap.timesig(playTickPos, z, n);
+            if (MusEGlobal::precountFromMastertrackFlag)
+                  AL::sigmap.timesig(curTickPos, z, n);
             else {
-                  z = precountSigZ;
-                  n = precountSigN;
+                  z = MusEGlobal::precountSigZ;
+                  n = MusEGlobal::precountSigN;
                   }
-            clickno       = z * preMeasures;
+            clickno       = z * MusEGlobal::preMeasures;
             clicksMeasure = z;
-            ticksBeat     = (division * 4)/n;
-*/
+            ticksBeat     = (MusEGlobal::config.division * 4)/n;
+
             }
       else {
             //
