@@ -236,7 +236,7 @@ void MidiDevice::recordEvent(MidiRecordEvent& event)
         event.setLoopNum(MusEGlobal::audio->loopCount());
       
       if (MusEGlobal::midiInputTrace) {
-            printf("MidiInput: ");
+            fprintf(stderr, "MidiInput: ");
             event.dump();
             }
 
@@ -288,7 +288,7 @@ void MidiDevice::recordEvent(MidiRecordEvent& event)
 
       if (!applyMidiInputTransformation(event)) {
             if (MusEGlobal::midiInputTrace)
-                  printf("   midi input transformation: event filtered\n");
+                  fprintf(stderr, "   midi input transformation: event filtered\n");
             return;
             }
 
@@ -313,7 +313,7 @@ void MidiDevice::recordEvent(MidiRecordEvent& event)
       // Split the events up into channel fifos. Special 'channel' number 17 for sysex events.
       unsigned int ch = (typ == ME_SYSEX)? MIDI_CHANNELS : event.channel();
       if(_recordFifo[ch].put(event))
-        printf("MidiDevice::recordEvent: fifo channel %d overflow\n", ch);
+        fprintf(stderr, "MidiDevice::recordEvent: fifo channel %d overflow\n", ch);
       }
 
 //---------------------------------------------------------
@@ -530,7 +530,7 @@ bool MidiDevice::putEvent(const MidiPlayEvent& ev)
                   sendNullRPNParams(t, port, chn, true);
                   }
             else {
-                  printf("putEvent: unknown controller type 0x%x\n", a);
+                  fprintf(stderr, "putEvent: unknown controller type 0x%x\n", a);
                   }
             return false;
 #endif
@@ -730,9 +730,16 @@ void MidiDevice::handleSeek()
         drum_found = true; 
         for(int i = 0; i < DRUM_MAPSIZE; ++i)
         {
-          if(MusEGlobal::drumMap[i].port != _port || usedChans[MusEGlobal::drumMap[i].channel])
+          // Default to track port if -1 and track channel if -1.
+          int mport = MusEGlobal::drumMap[i].port;
+          if(mport == -1)
+            mport = (*imt)->outPort();
+          int mchan = MusEGlobal::drumMap[i].channel;
+          if(mchan == -1)
+            mchan = (*imt)->outChannel();
+          if(mport != _port || usedChans[mchan])
             continue;
-          usedChans[MusEGlobal::drumMap[i].channel] = true;
+          usedChans[mchan] = true;
           ++usedChanCount;
           if(usedChanCount >= MIDI_CHANNELS)
             break;  // All are used, done searching.
