@@ -39,6 +39,7 @@
 #include "limits.h"
 #include "dssihost.h"
 #include "gconfig.h"
+#include <QMessageBox>
 
 namespace MusECore {
 
@@ -90,8 +91,11 @@ void addPortCtrlEvents(MidiTrack* t)
           {
             int note = cntrl & 0x7f;
             cntrl &= ~0xff;
-            ch = MusEGlobal::drumMap[note].channel;
-            mp = &MusEGlobal::midiPorts[MusEGlobal::drumMap[note].port];
+            // Default to track port if -1 and track channel if -1.
+            if(MusEGlobal::drumMap[note].channel != -1)
+              ch = MusEGlobal::drumMap[note].channel;
+            if(MusEGlobal::drumMap[note].port != -1)
+              mp = &MusEGlobal::midiPorts[MusEGlobal::drumMap[note].port];
             cntrl |= MusEGlobal::drumMap[note].anote;
           }
         }
@@ -132,8 +136,11 @@ void removePortCtrlEvents(MidiTrack* t)
           {
             int note = cntrl & 0x7f;
             cntrl &= ~0xff;
-            ch = MusEGlobal::drumMap[note].channel;
-            mp = &MusEGlobal::midiPorts[MusEGlobal::drumMap[note].port];
+            // Default to track port if -1 and track channel if -1.
+            if(MusEGlobal::drumMap[note].channel != -1)
+              ch = MusEGlobal::drumMap[note].channel;
+            if(MusEGlobal::drumMap[note].port != -1)
+              mp = &MusEGlobal::midiPorts[MusEGlobal::drumMap[note].port];
             cntrl |= MusEGlobal::drumMap[note].anote;
           }
         }
@@ -1146,8 +1153,10 @@ void MidiTrack::readOurDrumSettings(Xml& xml)
 				else if (tag == "ordering_tied") 
 					_drummap_ordering_tied_to_patch = xml.parseInt();
 				else if (tag == "our_drummap")
-					readOurDrumMap(xml);
-				else
+                    readOurDrumMap(xml, tag);
+                else if (tag == "drummap")
+                    readOurDrumMap(xml, tag, false);
+                else
 					xml.unknown("MidiTrack::readOurDrumSettings");
 				break;
 
@@ -1161,12 +1170,12 @@ void MidiTrack::readOurDrumSettings(Xml& xml)
 	}
 }
 
-void MidiTrack::readOurDrumMap(Xml& xml, bool dont_init)
+void MidiTrack::readOurDrumMap(Xml& xml, QString tag, bool dont_init, bool compatibility)
 {
   if (!dont_init) init_drummap(false);
   _drummap_tied_to_patch=false;
   _drummap_ordering_tied_to_patch=false;
-  read_new_style_drummap(xml, "our_drummap", _drummap, _drummap_hidden);
+  read_new_style_drummap(xml, tag.toLatin1().data(), _drummap, _drummap_hidden, compatibility);
   update_drum_in_map();
 }
 
