@@ -67,7 +67,7 @@ extern QColor readColor(MusECore::Xml& xml);
 namespace MusEGui {
 
 static int waveEditTools = MusEGui::PointerTool | MusEGui::PencilTool | MusEGui::RubberTool | 
-                           MusEGui::CutTool | MusEGui::CursorTool;
+                           MusEGui::CutTool | MusEGui::RangeTool | PanTool | ZoomTool;
 
 int WaveEdit::_rasterInit = 96;
 int WaveEdit::colorModeInit = 0;
@@ -161,9 +161,10 @@ WaveEdit::WaveEdit(MusECore::PartList* pl, QWidget* parent, const char* name)
       
       menuEdit->addSeparator();
 
-      adjustWaveOffsetAction = menuEdit->addAction(tr("Adjust wave offset..."));
-      mapper->setMapping(adjustWaveOffsetAction, WaveCanvas::CMD_ADJUST_WAVE_OFFSET);
-      connect(adjustWaveOffsetAction, SIGNAL(triggered()), mapper, SLOT(map()));
+// REMOVE Tim. Also remove CMD_ADJUST_WAVE_OFFSET and so on...      
+//       adjustWaveOffsetAction = menuEdit->addAction(tr("Adjust wave offset..."));
+//       mapper->setMapping(adjustWaveOffsetAction, WaveCanvas::CMD_ADJUST_WAVE_OFFSET);
+//       connect(adjustWaveOffsetAction, SIGNAL(triggered()), mapper, SLOT(map()));
       
       act = menuFunctions->addAction(tr("Mute Selection"));
       mapper->setMapping(act, WaveCanvas::CMD_MUTE);
@@ -298,7 +299,8 @@ WaveEdit::WaveEdit(MusECore::PartList* pl, QWidget* parent, const char* name)
       ymag->setFixedWidth(16);
       connect(canvas, SIGNAL(mouseWheelMoved(int)), this, SLOT(moveVerticalSlider(int)));
       connect(ymag, SIGNAL(valueChanged(int)), canvas, SLOT(setYScale(int)));
-      connect(canvas, SIGNAL(horizontalZoom(bool,int)), SLOT(horizontalZoom(bool,int)));
+      connect(canvas, SIGNAL(horizontalZoom(bool, const QPoint&)), SLOT(horizontalZoom(bool, const QPoint&)));
+      connect(canvas, SIGNAL(horizontalZoom(int, const QPoint&)), SLOT(horizontalZoom(int, const QPoint&)));
 
       time->setOrigin(0, 0);
 
@@ -334,8 +336,8 @@ WaveEdit::WaveEdit(MusECore::PartList* pl, QWidget* parent, const char* name)
       connect(MusEGlobal::song, SIGNAL(songChanged(MusECore::SongChangedFlags_t)), SLOT(songChanged1(MusECore::SongChangedFlags_t)));
 
       // For the wave editor, let's start with the operation range selection tool.
-      canvas->setTool(MusEGui::CursorTool);
-      tools2->set(MusEGui::CursorTool);
+      canvas->setTool(MusEGui::RangeTool);
+      tools2->set(MusEGui::RangeTool);
       
       setEventColorMode(colorMode);
       
@@ -683,8 +685,16 @@ void WaveEdit::keyPressEvent(QKeyEvent* event)
             tools2->set(MusEGui::CutTool);
             return;
             }
-      else if (key == shortcuts[SHRT_TOOL_CURSOR].key) {
-            tools2->set(MusEGui::CursorTool);
+      else if (key == shortcuts[SHRT_TOOL_PAN].key) {
+            tools2->set(MusEGui::PanTool);
+            return;
+            }
+      else if (key == shortcuts[SHRT_TOOL_ZOOM].key) {
+            tools2->set(MusEGui::ZoomTool);
+            return;
+            }
+      else if (key == shortcuts[SHRT_TOOL_RANGE].key) {
+            tools2->set(MusEGui::RangeTool);
             return;
             }
       else if (key == shortcuts[SHRT_EVENT_COLOR].key) {
@@ -698,21 +708,11 @@ void WaveEdit::keyPressEvent(QKeyEvent* event)
             
       // TODO: New WaveCanvas: Convert some of these to use frames.
       else if (key == shortcuts[SHRT_ZOOM_IN].key) {
-            int offset = 0;
-            QPoint cp = canvas->mapFromGlobal(QCursor::pos());
-            QPoint sp = mainw->mapFromGlobal(QCursor::pos());
-            if(cp.x() >= 0 && cp.x() < canvas->width() && sp.y() >= 0 && sp.y() < mainw->height())
-              offset = cp.x();
-            horizontalZoom(true, offset);
+            horizontalZoom(true, QCursor::pos());
             return;
             }
       else if (key == shortcuts[SHRT_ZOOM_OUT].key) {
-            int offset = 0;
-            QPoint cp = canvas->mapFromGlobal(QCursor::pos());
-            QPoint sp = mainw->mapFromGlobal(QCursor::pos());
-            if(cp.x() >= 0 && cp.x() < canvas->width() && sp.y() >= 0 && sp.y() < mainw->height())
-              offset = cp.x();
-            horizontalZoom(false, offset);
+            horizontalZoom(false, QCursor::pos());
             return;
             }
       else if (key == shortcuts[SHRT_GOTO_CPOS].key) {
@@ -783,7 +783,7 @@ void WaveEdit::moveVerticalSlider(int val)
       ymag->setValue(ymag->value() + val);
       }
 
-void WaveEdit::horizontalZoom(bool zoom_in, int pos_offset)
+void WaveEdit::horizontalZoom(bool zoom_in, const QPoint& glob_pos)
 {
   int mag = hscroll->mag();
   int zoomlvl = ScrollScale::getQuickZoomLevel(mag);
@@ -798,7 +798,19 @@ void WaveEdit::horizontalZoom(bool zoom_in, int pos_offset)
         zoomlvl--;
   }
   int newmag = ScrollScale::convertQuickZoomLevelToMag(zoomlvl);
-  hscroll->setMag(newmag, pos_offset);
+
+  QPoint cp = canvas->mapFromGlobal(glob_pos);
+  QPoint sp = mainw->mapFromGlobal(glob_pos);
+  if(cp.x() >= 0 && cp.x() < canvas->width() && sp.y() >= 0 && sp.y() < mainw->height())
+    hscroll->setMag(newmag, cp.x());
+}
+
+void WaveEdit::horizontalZoom(int mag, const QPoint& glob_pos)
+{
+  QPoint cp = canvas->mapFromGlobal(glob_pos);
+  QPoint sp = mainw->mapFromGlobal(glob_pos);
+  if(cp.x() >= 0 && cp.x() < canvas->width() && sp.y() >= 0 && sp.y() < mainw->height())
+    hscroll->setMag(hscroll->mag() + mag, cp.x());
 }
 
 //---------------------------------------------------------
